@@ -1,5 +1,6 @@
 import os
 
+
 TEST_PROJECT_ROOT = os.path.abspath(
     os.environ.get('TEST_PROJECT_ROOT', '/tmp/'),
 )
@@ -11,7 +12,7 @@ STATIC_ROOT = os.path.join(TEST_PROJECT_ROOT, 'bower_static')
 STATIC_URL = '/static/'
 
 BOWER_INSTALLED_APPS = (
-    'jquery',
+    'jquery#1.9',
     'underscore',
 )
 
